import os.path
import logging
import kraken.tools.TextUi as TextUi
import kraken.query.GenerateQuerySet as GenerateQuerySet
import kraken.entrytypes.MetaData as MetaData

#
#  Check the system parameters
# 
def execute(system, runtime):
   commands = [ 
      "Create the initial directories of the kraken",
      "Create a standard set of queries",
      "Check the kraken directories"      
   ]
   commandname = TextUi.inputMenu("Select the command to execute:", commands)
   if commandname == "Create the initial directories of the kraken":
       createInitialDirectories(system, create = 1)
       return
   if commandname == "Create a standard set of queries":
       createStandardSetOfFilters(system, runtime)
       return
   if commandname == "Check the kraken directories":
       createInitialDirectories(system, create = 0)
       return
       
    

def createStandardSetOfFilters(system, runtime):
    metadata = MetaData.loadMetaData(system, runtime)
    GenerateQuerySet.generateQuerySet(system, metadata)
    
errors = 0
checks = 0
creates = 0
    
def checkAndCreateDir(system, directory, create):
    global errors, checks, creates
    checks += 1
    system.addProperty(directory, os.path.normpath(system.getProperty(directory)))
    dirname = system.getProperty(directory)
    if (not os.path.isdir(dirname)):
       if create:
          try: 
             os.mkdir(dirname)
          except:
             logging.critical("Can not create directory " + dirname)
             errors += 1
       else: 
           logging.critical("The destination directory does not exist:" + 
              system.getProperty("destinationDir"))
           errors += 1
      
    
def createInitialDirectories(system, create):
    global errors, checks, creates
    checks = 0
    errors = 0
    creates = 0
    
    # Convert all the paths to the Unix path
    print "Checking destination directory..."
    checkAndCreateDir(system, "destinationDir", create)
                
    # the kraken dirs            
    print "Checking kraken directories..."
    checks += 1
    newDirs = []
    for a in system.getProperty("krakenDirs"):
        kdir = os.path.normpath(a)
        if (not os.path.isdir(kdir)):
           logging.critical("The kraken source directory does not exist:" + kdir)
           errors += 1
        newDirs.append(kdir)
    system.addProperty("krakenDirs", newDirs)
    
    # destination directory is a kraken dir.
    print "Checking if the destination dir is a kraken dir..."
    checks += 1
    if not (system.getProperty("destinationDir") in system.getProperty("krakenDirs")):
       logging.critical("The destination directory " + system.getProperty("destinationDir") + 
           " is not one of the kraken directories " + str(system.getProperty("krakenDirs")))
       errors += 1

    # the directory of the generated entries
    print "Checking the directory of generated entries..."
    checkAndCreateDir(system, "generatedEntryDir", create)
            
    # the staging dir            
    print "Checking the temporary (staging) directory..."
    checkAndCreateDir(system, "tempDir", create)

    # the filter dir            
    print "Checking the filter directory..."
    checkAndCreateDir(system, "filterDir", create)
        
    if errors == 0:
        print "\n\nThere were no errors. " + str(checks) + " checks performed.\n"
    else:
        print "\n\n" + str(errors) + " found out of " + str(checks) + " checks performed.\n"


