import sys
import shutil
import os.path
import logging
import pickle
import kraken.tools.Utils as Utils
from kraken.entrytypes.MetaData import loadMetaData
import kraken.Constants
import kraken.presentation.Presentation as Presentation
import kraken.query.FilterEditor as FilterEditor
import kraken.data.web
import kraken.tools.TextUi as TextUi

def description(system, runtime):
    t  = "Generates a HTML file from the content of the kraken. The default\n"
    t += "location of this file is " + os.path.join(system.getProperty("destinationDir"), kraken.Constants.DEFAULT_HTML_FILE) + "\n" 
    t += "but it can be changed using the --outputfile option. \n\n"
    t += "It is usually used together with a query.\n"
    return t

#
#  Writes out a list of the cocoon in the html format.
#
def execute(system, runtime):
    metadata = loadMetaData(system, runtime)

    menuitems = [
      "Generate all saved queries",
      "Generate for new query"
    ]
    val = TextUi.inputMenu("What's your choice", menuitems, default = "Generate all saved queries")
    
    if val == "Generate for new query":
      que = FilterEditor.createQueryWithVerify(system, metadata)
      rotateQueryFiles(system) 
      FILE = open(os.path.join( system.getProperty("filterDir"), "query_1" + kraken.Constants.EXTENSION_QUERY), "w")
      pickle.dump(que, FILE)
      FILE.close()      
      generateAllQueries(system, metadata)
    if val == "Generate all saved queries":
      print "Generate all queries"
      generateAllQueries(system, metadata)


def generateAllQueries(system, metadata):      
      lst = os.listdir(system.getProperty("filterDir"))
      for a in lst: 
           if a[-4:] != kraken.Constants.EXTENSION_QUERY:
               continue
           filterFile = os.path.join(system.getProperty("filterDir"), a)
           FILE = open(filterFile)
           que = pickle.load(FILE)
           FILE.close()
           outputFile = os.path.join(system.getProperty("htmlDir"), 
                     a[:-4]+".html")
           generateHtmlForQuery(system, metadata, que, outputFile)
      print "Now generate index"
      indexFile = os.path.join(system.getProperty("htmlDir"), "index.html")
      temp = Presentation.generateIndexWithLinks(system, metadata)
      Utils.writeOutput(system, indexFile, temp)

# Rotate the query files and return the new one
def rotateQueryFiles(system):
    print "Rotate query files"
    for i in range(9, 0, -1):
       src = os.path.join(system.getProperty("filterDir"), "query_" + str(i) + kraken.Constants.EXTENSION_QUERY)
       if not os.path.exists(src):
           print "Can not find " + src
           continue
       dst = os.path.join(system.getProperty("filterDir"), "query_" + str(i+1) + kraken.Constants.EXTENSION_QUERY)
       print "source", src, "dest", dst
       os.rename(src, dst)                  
    return
      
       
def generateHtmlForQuery(system, metadata, query, outputFile):
      md = query.processMetaData(metadata)
      temp = Presentation.generateHtml(system, md)
      Utils.writeOutput(system, outputFile, temp)
      # and now copy the *.css
      scriptpath = kraken.data.web.__path__[0]      
      # copy everything from the scriptpath to the html file. 
      lst = os.listdir(scriptpath)
      for a in lst:
         src = os.path.join(scriptpath,a)
         if os.path.isdir(src):
             continue
         shutil.copy(src, system.getProperty("htmlDir"))
      print "HTML file generated successfully"
    
