import time
import os.path
import kraken.Constants
import pickle
from TableFormat import TableFormat
import FieldHelper
import kraken.entrytypes.MetaData as MetaData
import kraken.Version               
import string
        
# ***********************************************************
#  Generate web page
# ***********************************************************

def htmlBegin(cssFile = kraken.Constants.DEFAULT_CSS_FILENAME):
       temp = "";
       temp += "<html>\n"
       temp += "<head>\n"
       temp += '<link HREF="' + cssFile + '" REL="STYLESHEET" LANG="en.us">'
       temp += "</head>\n"
       return temp
       
def htmlEnd():
       temp = "</html>\n"
       return temp

       
def generateKrakenHeaderRow(title):
    temp = ""
    temp += '<tr>\n'
    temp += '<td class=pagetable-header colspan=2>\n'
    temp += '<table><tr><td><a href="index.html"><img src="kraken_small.jpg" height="80"/></a></td>'
    temp += '<td><h1 class=pagetable-header>' + title + '</h1>'
    temp +=('<p class=pagetable-header><b>Generated by: Kraken </b>' + kraken.Version.versionNumber + " on " + 
             time.strftime("%a, %d %b %Y %H:%M", time.localtime()))
    temp += '</td></tr></table>'
    temp += '</td>\n'
    temp += '</tr>\n'
    return temp    
       
def generatePageTable(maintable, smallTables, title="Kraken"):
    temp = '<table class=pagetable cols=2 cellspacing="20" width="100%">\n'
    # the header
    temp += generateKrakenHeaderRow(title)
    # the main pages
    temp += '<tr>\n'
    temp += '<td class=pagetable-main width="70%">\n'
    temp += maintable
    temp += '</td>\n'    
    # here come the secondary tables
    temp += '<td class=pagetable-sidebar>\n'
    temp += '<table class=sidebar width="100%" cellspacing="0">\n'
    for smalltable in smallTables:
       temp += '<tr>\n'
       temp += '<td class=sidebar-cell>\n'
       temp += smalltable
       temp += '</td>\n'
       temp += '</tr>\n'
    temp += '</table>\n'
    
    temp += '</td>\n</tr>\n'    
    temp += '</table> <!-- pagetable-->\n'
    return temp
       
   
def generateMainTable(system, metadata):
   headertext = generateHeader(system, metadata)
   temp = ""
   tf = TableFormat()
   temp += tf.generateEntryTable(metadata, headertext)
   return temp 
   
       
def generateHtml(system, metadata):
   temp = htmlBegin()
   maintable = generateMainTable(system, metadata)
   smalltables = []
   smalltables.append(generateSmallTableWithQueries(system, metadata))

   fullMetaData = MetaData.loadMetaData(system, None)
   lst = os.listdir(system.getProperty("filterDir"))
   for a in lst: 
       if a[-4:] != kraken.Constants.EXTENSION_QUERY:
          continue
       if string.find(a, "smalltable") == -1:
          continue
       smalltables.append(generateSmallTableFromQuery(system, a, a[:-15], fullMetaData))
   temp += generatePageTable(maintable, smalltables, "kraken:" + metadata.theQuery.name)       
   temp += htmlEnd()
   return temp

def generateSmallTableFromQuery(system, queryName, header, metadata):
     filterFile = os.path.join(system.getProperty("filterDir"), queryName)
     FILE = open(filterFile)
     query = pickle.load(FILE)
     FILE.close()
     
     md = query.processMetaData(metadata)
     temp = '<table class=smalltable width="100%" cellspacing="0">'
     temp += '<tr>'
     temp += '<td class=smalltable-header width=100%>'
     temp += header
     temp += '</td>'
     temp += '</tr>'
     cellClass = "smalltable-even"
     for entry in md.entries:
         if cellClass == "smalltable-even":
             cellClass = "smalltable-odd"
         else:
             cellClass = "smalltable-even"
         temp += '<tr>\n<td class=' + cellClass + '>'
         temp += FieldHelper.linkLocalFiles(entry, metadata)
     temp +='</table>'
     return temp
    
       
def generateSmallTableWithQueries(system, metadata):       
      lst = os.listdir(system.getProperty("filterDir"))
      links = []
      labels = []
      for a in lst: 
           if a[-4:] != kraken.Constants.EXTENSION_QUERY:
               continue
           # don't add the smalltables
           if string.find(a, "smalltable") != -1:
               continue
           if string.find(a, "query_") == 0:
               links.append( (a[:-4]+".html", "Recent query no." + a[6]) )
               continue               
           # load the query, get its names                         
           queryFile = os.path.join(system.getProperty("filterDir"), a)
           FILE = open(queryFile)
           query = pickle.load(FILE)
           FILE.close()
           links.append( (a[:-4]+".html", query.name) )

           
      temp = '<table class=smalltable width="100%" cellspacing="0">'
      temp += '<tr>'
      temp += '<td class=smalltable-header width=100%>'
      temp += 'Saved queries'
      temp += '</td>'
      temp += '</tr>'
      cellClass = "smalltable-even"
      for a in links:
         if cellClass == "smalltable-even":
             cellClass = "smalltable-odd"
         else:
             cellClass = "smalltable-even"
         temp += '<tr>\n<td class=' + cellClass + '>'
         temp += '<a href="' + a[0] + '">' + a[1] + '</a>'
      temp +='</table>'
      return temp
       
       
def generateIndexWithLinks(system, metadata):
       temp = htmlBegin()
       temp += '<table class=pagetable cols=2 cellspacing="20" width="100%">\n'
       # the header
       temp += generateKrakenHeaderRow("Kraken:Index")
       temp += "<tr>\n<td>\n"
       temp += generateSmallTableWithQueries(system, metadata)       
       temp += "</td>\n</tr>\n"
       temp += "</table>\n"
       temp += htmlEnd()
       return temp       
       
def generateHeader(system, metadata):
    temp = "<tr>\n<td class=maintable-header colspan=2>"
    temp += "<pre>" + str(metadata.theQuery) + "</pre><br/>"
    temp += "<td></tr>"
    return temp


